#
# spec file for package python-django-extensions
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-extensions
Version:        3.2.3
Release:        4.2
Summary:        Extensions for Django
License:        BSD-3-Clause
URL:            https://github.com/django-extensions/django-extensions
Source:         https://github.com/django-extensions/django-extensions/archive/%{version}.tar.gz#/django-extensions-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
# not compatible with Django 5.1 yet
Requires:       (python-Django >= 3.2 with python-Django < 5.1)
Recommends:     python-Pygments
Recommends:     python-Werkzeug
Recommends:     python-django-json-widget
Recommends:     python-djangorestframework >= 3.0.0
Recommends:     python-python-dateutil
Suggests:       python-pip >= 20.1
Suggests:       python-pydot
Suggests:       python-pygraphviz
Suggests:       python-requests
Suggests:       python-shortuuid
BuildArch:      noarch
# SECTION test requirements
# See https://github.com/django-extensions/django-extensions/issues/1617
# for optional dependency django-pdb
BuildRequires:  %{python_module Django >= 3.2 with %python-Django < 5.1}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module django-json-widget}
BuildRequires:  %{python_module djangorestframework >= 3.0.0}
BuildRequires:  %{python_module factory_boy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pydot}
BuildRequires:  %{python_module pygraphviz}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module shortuuid}
BuildRequires:  %{python_module vobject}
# /SECTION test
%python_subpackages

%description
Django-extensions bundles several useful
additions for Django projects.

%prep
%autosetup -p1 -n django-extensions-%{version}
rm setup.cfg

# Most PipCheckerTests tests fail when using network to connect to PyPI
sed -i 's/djangorestframework==[0-9.]*/djangorestframework/g;s/pip==[0-9.]*/pip/g' tests/management/commands/test_pipchecker.py

%build
export LANG=en_US.UTF-8
%python_build

%install
export LANG=en_US.UTF-8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
export DJANGO_SETTINGS_MODULE=tests.testapp.settings
export PYTHONPATH=${PWD}

# mail_debug depends on asyncore and smtpd, which have been removed from Python 3.12
# There is a PR upstream for this already, but it isnt well tested.
# Remove this when https://github.com/django-extensions/django-extensions/issues/1831 is resolved.
rm django_extensions/management/commands/mail_debug.py tests/management/commands/test_mail_debug.py

skips="(PipCheckerTests and not test_pipchecker_when_requirements_file_does_not_exist)"
# test_no_models_dot_py fails to generate a .dot file
skips="$skips or test_no_models_dot_py"
# missing fixtures in sdist
skips="$skips or test_migration_is_last_applied or test_installed_apps_no_resolve_conflicts_function or test_validate_templates"

# test_should_colorize_noclasses_with_default_lexer can sometimes fail with minor html output differences
# when pygments is updated.  Uncomment this when that occurs, and raise an issue upstream.
#skips="$skips or test_should_colorize_noclasses_with_default_lexer"

# many DumpScriptTests fail with pytest 8 https://github.com/django-extensions/django-extensions/issues/1877
skips="$skips or DumpScriptTests"

# test_export_emails, test_set_fake_emails and test_set_fake_emails fail in setup due to missing fixtures in sdist
%pytest -rs -v -k "not ($skips)" --ignore tests/management/commands/test_set_fake_passwords.py --ignore tests/management/commands/test_set_fake_emails.py --ignore tests/management/commands/test_export_emails.py

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.rst docs/*.rst
%{python_sitelib}/*django[-_]extensions*/

%changelog
* Mon Dec 16 2024 Markéta Machová <mmachova@suse.com>
- Fix build
  * use older Django, not compatible with the new one
  * skip tests failing with new pytest
* Tue Feb  6 2024 John Vandenberg <jayvdb@gmail.com>
- Fix Python 3.12 by disabling mail_debug testing.
- Re-enable some other tests
* Fri Jun 23 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 3.2.3:
  * Fix error with lack of PosixPath support
  * Import pkg_resources directly
  * Add REMOTE_USER to werkzeug environment
  * runserver_plus template reloading
  * Add Python 3.11 support
  * Run tests againts Django 4.2 and add trove classifier
  * fix: test_should_highlight_bash_syntax_without_name to
    include whites…
  * Add support for psycopg3
  * Fixed drop test database command with psycopg 3
  * Fixed reset_db with psycopg3 (same patch like for
    drop_test_database)
* Sat Jan 28 2023 John Vandenberg <jayvdb@gmail.com>
- Skip one test that has started failing due to minor HTML output
  changes.
* Sun Sep 18 2022 John Vandenberg <jayvdb@gmail.com>
- Remove patches merged upstream:
  * pr_1698.patch
  * remove-mock.patch
  * support-werkzeug-2-1.patch
- Add skips for tests depending on missing test data
- Update to v3.2.1
  * Improvement: fix translation interpolation in prospective arabic translations
  * Improvement: runserver_plus, Add option to ignore files on runserver_plus reload
  * Improvement: docs: Fix a few typos
  * Improvement: drop python 3.5 as it is EOL
  * Improvement: sqldiff, Added support for meta indexes and constraints in sqldiff
  * Improvement: show_urls, Ensure consistent output in show_urls for django 4.0+
  * Fix: dumpscript, make_aware should not be called if aware already
  * Fix: Use list values for requires_system_checks
- from v3.2.0
  * Improvement: Django 4 support
  * Improvement: Accept both --no-input and --noinput
  * Improvement: sqldsn, Added more styles to the sqldsn management command
  * Improvement: graph_models, Flag for to color code relations based on on_delete
  * Improvement: graph_models, Add --relation-fields-only flag
  * Improvement: RandomCharField, allow keeping default values
  * Fix: HexValidator, Max length validation
  * Fix: runserver_plus, Fix KeyError: 'werkzeug.server.shutdown'
  * New: managestate, Saves current applied migrations to a file or applies migrations from file
* Fri May  6 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-mock.patch:
  * Use stdlib mock.
- Remove BuildRequires on mock
- Add patch support-werkzeug-2-1.patch:
  * Support Werkzeug >= 2.1.0
* Sun Jan  9 2022 John Vandenberg <jayvdb@gmail.com>
- Relax dependency on optional dependency pip to allow building on
  Leap
- Add pr_1698.patch for Django 4.0 support
- Update to v3.1.5
  * fix for removed get_installed_distributions function
  * crude way slow down to avoid HTTPTooManyRequests
  * ignore failing get_installed_distributions import for mypy
- from v3.1.4
  * Fix: set_default_site, improve django.contrib.sites application detection
  * Improvement: documentation, Fix name of mixin in docs
  * Improvement: mypy, type ignore backwards compatible imports
  * Improvement: graph_models, add --rankdir to change graph direction
  * Improvement: runserver_plus, Add --sql-truncate cli modifier
  * Improvement: shell_plus, Add --sql-truncate cli modifier
- from v3.1.3
  * Fix: Django 3.2, Run tests against Django 3.2
  * Fix: Django 3.2, Handle warnings for default_app_config (#1654)
  * Fix: sqldiff, Fix for missing field/index in model case
* Thu Dec  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop python 3.6 support since python-pygraphviz dropped it
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- Update to 3.1.3
  * add option --app-labels to graph_models
  * Handle warnings for default_app_config in Django 3.2
* Tue Jan 12 2021 John Vandenberg <jayvdb@gmail.com>
- Run spec-cleaner and remove url from description
- Remove conf.py from %%doc
- Add Suggests for requests, pygraphviz and pydot
- Add minimum versions for pip and djangorestframework
- Re-activate several tests and de-select two tests
- Update to v3.1.0
  * pipchecker, sleep 60s if pypi raises a fault
  * add django_zero_downtime_migrations to list of supported
    postgresql engines
  * use list of supported database engines from settings for all
    database commands
  * reset_db, documentation
  * Fix: tests, Python 3.9 fixes for some tests
  * Fix: runserver_plus, parsing of RUNSERVER_PLUS_EXTRA_FILES
- from v3.0.9
  * runserver_plus, survive syntax and configuration errors part II
  * tests, refactor test runner
  * sqlcreate, support postgresql unix domain socket
- from v3.0.8
  * setup.cfg, remove universal flag from wheel, as Python 3 only
  * sqlcreate, fixed mentioned of old syncdb
  * runserver_plus, stop catching SyntaxError since reload for
    it was not working properly
- from v3.0.7
  * runserver_plus, gh #1575 survive syntax and configuration errors
  * runscript, use exit-code 1 if script is not found
- from v3.0.6
  * runscript, add --continue-on-error unless set runscript will
    exit on errors
  * runscript, allow to return exit-code
  * runscript, support raise CommandError(... returncode=...)
  * runscript, run Django checks() and check_migrations() before
    executing scripts
  * shell_plus, set application name on all postgresql backends
- from v3.0.5
  * runserver_plus, exceptions must derive from BaseException error
- from v3.0.4
  * Various cleanups
  * Deprecated using `--router` instead use `--database`
  * Locales: Indonesian and Polish, updated
  * show_dsn, fix crash with django-postgres-extra
  * print_settings, added wildcard support
  * print_settings, added --fail option
  * delete_squashed_migrations, add --database option
  * runserver_plus, added RUNSERVER_PLUS_EXTRA_FILES setting
  * runserver_plus, added runserver_plus_started signal
- from v3.0.3
  * New: InternalIPS, allows to specify CIDRs for INTERNAL_IPS
  * Docs: restructure toctree
* Tue Jul  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 3.0.2
  * Django 2.2 and above only
  * Removal of Python 2 support
  * Removal of deprecated keyczar encrypted fields EncryptedTextField and EncryptedCharField
  * Removal of deprecated passwd command
  * Removal of truncate_letters filter
  * Change: TimeStampedModel; Removed default ordering on abstract model
  * New: DjangoExtensionsConfig AppConfig
  * New: shell_plus, JupyterLab support
  * New: list_signals, List all signals by model and signal type
  * Improvement: shell_plus, use -- to directly pass additional arguments to Jupyter
  * Improvement: shell_plus, improvements to MySQL support
  * Improvement: jobs, use logging to record errors
  * Improvement: syncdata, added --remove-before flag
  * Improvement: graph_models, add field and model to template context
  * Fix: syncdata, fix non existent field in fixture data
  * Fix: pipchecker, compatibility with pip 20.1
* Fri Apr  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.9:
  * Fix: shell_plus, move notebook down the list of prefered shells
  * Fix: sqldiff, fix KeyError when detecting missing (unique) indexes
  * Improvement: encrypted fields, make it harder to use deprecated keyczar fields
  * Locale: Removed empty localizations
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.8:
  * Various small fixes
* Mon Jan 13 2020 pgajdos@suse.com
- fix build in SLE-15: set en_US.UTF-8 encoding
* Wed Oct 30 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.5:
  * RandomCharField, Support unique_together
  * export_emails, add settings for overriding queryset fields, order_by and the full_name function
* Mon Oct  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.3:
  * minor fixes
- Disable py2 package due to unsattisfied dependencies
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.1:
  * More tests
  * Many bugfixes
  * Fixes for newest pytest/django
* Fri Sep 13 2019 John Vandenberg <jayvdb@gmail.com>
- Use have/skip_python2/3 macros to allow building only one package
* Tue Mar 12 2019 John Vandenberg <jayvdb@gmail.com>
- Activate the test suite
- Add missing Requires python-six
- Add Recommends and Suggests
- Add fdupes
- Update to v2.1.6
* Sat Feb 16 2019 John Vandenberg <jayvdb@gmail.com>
- Use single spec style
- Use %%license
- Add missing Requires python-Django
- Update to v2.1.5
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 1.2.2
  + No changelog available
- Use download url as source
- Copy documentation from tarball
* Sun Jan 27 2013 alexandre@exatati.com.br
- Update to 1.0.3:
  - Sorry, no changelog atm.
* Mon Dec 17 2012 alexandre@exatati.com.br
- Update to 1.0.2:
  - Sorry, no changelog atm.
* Thu Nov  8 2012 alexandre@exatati.com.br
- Update to 1.0.1:
  - Sorry, no changelog atm.
* Mon Oct 22 2012 alexandre@exatati.com.br
- Update to 1.0.0:
  - Sorry, no changelog atm.
* Fri Jun  8 2012 alexandre@exatati.com.br
- Update to 0.9:
  - Sorry, no changelog atm.
* Mon Feb 27 2012 alexandre@exatati.com.br
- Update to 0.8:
  - Sorry, no changelog atm.
* Mon Oct 17 2011 alexandre@exatati.com.br
- Update to 0.7.1:
  - Sorry, no changelog atm.
- Regenerate spec file with py2pack;
- Bzip2 source code.
* Fri Apr 23 2010 alexandre@exatati.com.br
- Update to 0.5;
- Spec file cleaned with spec-cleaner;
- Building as noarch for openSUSE >= 11.2;
- Fixed Author, Description, Summary and URL tags in spec file.
